summaryrefslogtreecommitdiffstats
path: root/src/notefactory.cpp
diff options
context:
space:
mode:
authorTimothy Pearson <kb9vqf@pearsoncomputing.net>2013-01-25 00:05:29 -0600
committerTimothy Pearson <kb9vqf@pearsoncomputing.net>2013-01-25 00:05:29 -0600
commite54e867af243223a620f12bf260e1af9ac9f6dc5 (patch)
tree0e741cd6800d16c390671051ae525f760d87cdb5 /src/notefactory.cpp
parent934db26c3f8efe148a5680c22f965ee10f818a61 (diff)
downloadbasket-e54e867af243223a620f12bf260e1af9ac9f6dc5.tar.gz
basket-e54e867af243223a620f12bf260e1af9ac9f6dc5.zip
Rename KCModule, KConfig, KIO, KServer, and KSocket to avoid conflicts with KDE4
Diffstat (limited to 'src/notefactory.cpp')
-rw-r--r--src/notefactory.cpp26
1 files changed, 13 insertions, 13 deletions
diff --git a/src/notefactory.cpp b/src/notefactory.cpp
index f35728b..ee14c5c 100644
--- a/src/notefactory.cpp
+++ b/src/notefactory.cpp
@@ -686,15 +686,15 @@ Note* NoteFactory::copyFileAndLoad(const KURL &url, Basket *parent)
// parent->dontCareOfCreation(fullPath);
-// KIO::CopyJob *copyJob = KIO::copy(url, KURL(fullPath));
-// parent->connect( copyJob, TQT_SIGNAL(copyingDone(KIO::Job *, const KURL &, const KURL &, bool, bool)),
-// parent, TQT_SLOT(slotCopyingDone(KIO::Job *, const KURL &, const KURL &, bool, bool)) );
+// TDEIO::CopyJob *copyJob = TDEIO::copy(url, KURL(fullPath));
+// parent->connect( copyJob, TQT_SIGNAL(copyingDone(TDEIO::Job *, const KURL &, const KURL &, bool, bool)),
+// parent, TQT_SLOT(slotCopyingDone(TDEIO::Job *, const KURL &, const KURL &, bool, bool)) );
- KIO::FileCopyJob *copyJob = new KIO::FileCopyJob(
+ TDEIO::FileCopyJob *copyJob = new TDEIO::FileCopyJob(
url, KURL(fullPath), 0666, /*move=*/false,
/*overwrite=*/true, /*resume=*/true, /*showProgress=*/true );
- parent->connect( copyJob, TQT_SIGNAL(result(KIO::Job *)),
- parent, TQT_SLOT(slotCopyingDone2(KIO::Job *)) );
+ parent->connect( copyJob, TQT_SIGNAL(result(TDEIO::Job *)),
+ parent, TQT_SLOT(slotCopyingDone2(TDEIO::Job *)) );
NoteType::Id type = typeForURL(url, parent); // Use the type of the original file because the target doesn't exist yet
@@ -703,7 +703,7 @@ Note* NoteFactory::copyFileAndLoad(const KURL &url, Basket *parent)
Note* NoteFactory::moveFileAndLoad(const KURL &url, Basket *parent)
{
// Globally the same as copyFileAndLoad() but move instead of copy (KIO::move())
TQString fileName = fileNameForNewNote(parent, url.fileName());
TQString fullPath = parent->fullPathForFileName(fileName);
@@ -714,15 +714,15 @@ Note* NoteFactory::moveFileAndLoad(const KURL &url, Basket *parent)
// parent->dontCareOfCreation(fullPath);
-// KIO::CopyJob *copyJob = KIO::move(url, KURL(fullPath));
-// parent->connect( copyJob, TQT_SIGNAL(copyingDone(KIO::Job *, const KURL &, const KURL &, bool, bool)),
-// parent, TQT_SLOT(slotCopyingDone(KIO::Job *, const KURL &, const KURL &, bool, bool)) );
+// TDEIO::CopyJob *copyJob = TDEIO::move(url, KURL(fullPath));
+// parent->connect( copyJob, TQT_SIGNAL(copyingDone(TDEIO::Job *, const KURL &, const KURL &, bool, bool)),
+// parent, TQT_SLOT(slotCopyingDone(TDEIO::Job *, const KURL &, const KURL &, bool, bool)) );
- KIO::FileCopyJob *copyJob = new KIO::FileCopyJob(
+ TDEIO::FileCopyJob *copyJob = new TDEIO::FileCopyJob(
url, KURL(fullPath), 0666, /*move=*/true,
/*overwrite=*/true, /*resume=*/true, /*showProgress=*/true );
- parent->connect( copyJob, TQT_SIGNAL(result(KIO::Job *)),
- parent, TQT_SLOT(slotCopyingDone2(KIO::Job *)) );
+ parent->connect( copyJob, TQT_SIGNAL(result(TDEIO::Job *)),
+ parent, TQT_SLOT(slotCopyingDone2(TDEIO::Job *)) );
NoteType::Id type = typeForURL(url, parent); // Use the type of the original file because the target doesn't exist yet
@@ -703,7 +703,7 @@ Note* NoteFactory::copyFileAndLoad(const KURL &url, Basket *parent)
Note* NoteFactory::moveFileAndLoad(const KURL &url, Basket *parent)
{
- // Globally the same as copyFileAndLoad() but move instead of copy (KIO::move())
+ // Globally the same as copyFileAndLoad() but move instead of copy (TDEIO::move())
TQString fileName = fileNameForNewNote(parent, url.fileName());
TQString fullPath = parent->fullPathForFileName(fileName);